var layout = 
{
	/* true if the layout must use softkeys
	 * false if the layout must use toolbar buttons
	 */
	useSoftkeys: false,
	
	/* CSS class applied to the buttons' toolbar */
	toolbarButtonCssClass: 'toolbar_button',
	
	/* holds a reference to the currently displayed view */
	currentScreen: null,
	
	/* value of the last detected display width */
	lastDetectedWidth: 0,
	
	/* value of the last detected display height */
	lastDetectedHeight: 0,
	
	/* custom resize handler */
	customResizeHandler: null,
	
	init: function(startScreen)
	{
		this.setupInterface();
	
		var self = this;
	
		setInterval(
			function()
			{
				self.pollResize();
			}
			, 
			1000
		);
		
		window.addEventListener(
			'resize', 
			function()
			{
				self.onResize();
			}, 
			false
		);
		
		this.gotoScreen(startScreen);
	},
	
	onResize: function()
	{
		this.setupInterface();
		
		if(this.customResizeHandler)
		{
			this.customResizeHandler();
		}
	},
	
	isLandscape: function()
	{
		return window.innerWidth > window.innerHeight;
	},

	pollResize: function()
	{
		if(window.innerWidth != this.lastDetectedWidth || window.innerHeight != this.lastDetectedHeight)
		{
			this.onResize();
		}
	},
	
	addMainOption: function(text, id, handler)
	{
		if(this.useSoftkeys)
		{
			var item = new MenuItem(text, id);
			
			item.onSelect = handler;
			
			menu.append(item);
			
			return item;
		}
		else
		{
			var button = document.createElement('div');
			
			button.className = this.toolbarButtonCssClass;
			
			button.appendChild(document.createTextNode(text));
			
			button.feedback = "100";
			
			button.onclick = handler;
			
			$('toolbar_buttons').appendChild(button);
			
			return button;
		}
	},
	
	setupInterface: function()
	{
		if(!this.useSoftkeys)
			menu.hideSoftkeys();
		else
		{
			$('bottom_toolbar').style.display = 'none';
			menu.showSoftkeys();
		}
			
		
		this.lastDetectedWidth = window.innerWidth;
		this.lastDetectedHeight = window.innerHeight;
		
		if(this.useSoftkeys)
		{
			$('screen_container').style.width = this.lastDetectedWidth + 'px';
			
			$('screen_container').style.height = 
				(this.lastDetectedHeight - $('header').offsetHeight - $('ticker_container').offsetHeight) + 'px';
		}
		else if(this.isLandscape())
		{
			$('bottom_toolbar').style.display = 'none';
			$('right_toolbar').style.display = '';
			$('right_toolbar').appendChild($('toolbar_buttons'));
			
			$('right_toolbar').style.height = 
				(this.lastDetectedHeight - $('header').offsetHeight - $('ticker_container').offsetHeight) + 'px';
				
			$('screen_container').style.width = (this.lastDetectedWidth - $('right_toolbar').offsetWidth) + 'px';
			
			$('screen_container').style.height = 
				(this.lastDetectedHeight - $('header').offsetHeight - $('ticker_container').offsetHeight) + 'px';
		}
		else
		{
			$('screen_container').style.width = this.lastDetectedWidth + 'px';
			
			$('bottom_toolbar').style.display = '';
			$('right_toolbar').style.display = 'none';
			$('bottom_toolbar').appendChild($('toolbar_buttons'));		
			
			$('screen_container').style.height = 
				(this.lastDetectedHeight - $('header').offsetHeight - $('ticker_container').offsetHeight - $('toolbar_buttons').offsetHeight) + 'px';
		}
	},
	gotoScreen: function(screenId, clearHistory)
	{
		var newScreen = $(screenId);
		
		if(newScreen)
		{
			if(this.currentScreen != null)
			{
				this.currentScreen.style.display = 'none';
			}
			this.currentScreen = newScreen;
			
			this.currentScreen.style.display = '';
		}
	}	
};


